require 'logger'

# Base module for the ezdyn gem. Offers logging functionality via module
# methods #debug and #info.
#
# Set the environment variable `EZDYN_DEBUG` to any value to enable debug
# logging to `stderr`.
#
module EZDyn
  # @private
  class EZDynLog
    attr_reader :logger

    def initialize
      @logger = Logger.new(STDERR)
      @logger.level = Logger::DEBUG
      @logger.datetime_format = '%Y-%m-%d %H:%M:%S'
      @logger.formatter =
        proc do |sev, dt, prog, msg|
          "#{dt} #{sev}: #{msg}\n"
        end
      @logger.debug { "Logger initialized" }
    end
  end

  # @private
  @@logger =
    if ENV["EZDYN_DEBUG"]
      EZDyn::EZDynLog.new
    end

  # Logs a debug message to the default logger containing the value yielded
  # by the given block.
  def self.debug &block
    if block_given? and not @@logger.nil?
      @@logger.logger.debug { yield }
    end
  end

  # Logs an info-level message to the default logger containing the value yielded
  # by the given block.
  def self.info &block
    if block_given? and not @@logger.nil?
      @@logger.logger.info { yield }
    end
  end
end
